@@ -6,7 +6,7 @@ import random
 import string
 import time
 import beartype  # to trigger the runtime typechecking
-import json # Added for CLI test payload generation
+import json  # Added for CLI test payload generation
 
 # Import API, errors, and datatypes from the main package
 from karakeep_python_api import KarakeepAPI, APIError, AuthenticationError, datatypes
@@ -30,12 +30,16 @@ def test_get_all_bookmarks_paginated(karakeep_client: KarakeepAPI):
 
         # If there's a next cursor, get the next page
         if page1.nextCursor:
-            logger.info(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
+            logger.info(
+                f"  Attempting to fetch next page with cursor: {page1.nextCursor}"
+            )
             page2 = karakeep_client.get_all_bookmarks(limit=2, cursor=page1.nextCursor)
             assert isinstance(page2, datatypes.PaginatedBookmarks)
             assert isinstance(page2.bookmarks, list)
             assert len(page2.bookmarks) <= 2
-            logger.info(f"✓ Retrieved second page with {len(page2.bookmarks)} bookmarks.")
+            logger.info(
+                f"✓ Retrieved second page with {len(page2.bookmarks)} bookmarks."
+            )
             # Ensure bookmarks are different from page 1 (simple check)
             if page1.bookmarks and page2.bookmarks:
                 assert (
@@ -163,12 +167,16 @@ def test_get_all_highlights_paginated(karakeep_client: KarakeepAPI):
 
         # If there's a next cursor, get the next page
         if page1.nextCursor:
-            logger.info(f"  Attempting to fetch next page with cursor: {page1.nextCursor}")
+            logger.info(
+                f"  Attempting to fetch next page with cursor: {page1.nextCursor}"
+            )
             page2 = karakeep_client.get_all_highlights(limit=3, cursor=page1.nextCursor)
             assert isinstance(page2, datatypes.PaginatedHighlights)
             assert isinstance(page2.highlights, list)
             assert len(page2.highlights) <= 3
-            logger.info(f"✓ Retrieved second page with {len(page2.highlights)} highlights.")
+            logger.info(
+                f"✓ Retrieved second page with {len(page2.highlights)} highlights."
+            )
             # Ensure highlights are different from page 1 (simple check)
             if page1.highlights and page2.highlights:
                 assert (
@@ -257,11 +265,15 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
     try:
         # 1. Generate a unique list name
         timestamp = int(time.time())
-        random_suffix = "".join(random.choices(string.ascii_lowercase + string.digits, k=6))
+        random_suffix = "".join(
+            random.choices(string.ascii_lowercase + string.digits, k=6)
+        )
         list_name = f"Test List {timestamp}-{random_suffix}"
         list_icon = "🧪"  # Test tube icon
 
-        logger.info(f"\nAttempting to create list: Name='{list_name}', Icon='{list_icon}'")
+        logger.info(
+            f"\nAttempting to create list: Name='{list_name}', Icon='{list_icon}'"
+        )
 
         # 2. Get initial list count (optional, for comparison)
         initial_lists = karakeep_client.get_all_lists()
@@ -270,9 +282,7 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
 
         # 3. Create the new list
         created_list = karakeep_client.create_a_new_list(
-            name=list_name,
-            icon=list_icon,
-            list_type="manual"
+            name=list_name, icon=list_icon, list_type="manual"
         )
         assert isinstance(
             created_list, datatypes.ListModel
@@ -294,7 +304,6 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
         logger.info(f"  List count after creation: {len(current_lists_after_create)}")
         logger.info(f"✓ Verified list {created_list_id} is present in get_all_lists.")
 
-
         # 5. Verify the list exists by getting it directly (redundant but good check)
         retrieved_list = karakeep_client.get_a_single_list(list_id=created_list_id)
         assert isinstance(retrieved_list, datatypes.ListModel)
@@ -304,7 +313,9 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during list creation/verification: {e}")
     except Exception as e:
-        pytest.fail(f"An unexpected error occurred during list creation/verification: {e}")
+        pytest.fail(
+            f"An unexpected error occurred during list creation/verification: {e}"
+        )
     finally:
         # 6. Delete the list (ensure cleanup even if assertions fail)
         if created_list_id:
@@ -342,21 +353,27 @@ def test_create_and_delete_list(karakeep_client: KarakeepAPI):
             except Exception as e:
                 pytest.fail(f"An unexpected error occurred during list deletion: {e}")
         else:
-            logger.info("\nSkipping deletion because list creation failed or ID was not obtained.")
+            logger.info(
+                "\nSkipping deletion because list creation failed or ID was not obtained."
+            )
 
 
-def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark):
+def test_create_and_delete_bookmark(
+    karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark
+):
     """
     Test verifying a created bookmark (via fixture) and searching for it.
     The fixture handles creation and deletion.
     """
     created_bookmark_id = managed_bookmark.id
-    test_url = managed_bookmark.content.url # Get URL from fixture
-    original_title = managed_bookmark.title # Get title from fixture
+    test_url = managed_bookmark.content.url  # Get URL from fixture
+    original_title = managed_bookmark.title  # Get title from fixture
 
     try:
         # 1. Bookmark is already created by the 'managed_bookmark' fixture.
-        logger.info(f"\nUsing managed bookmark ID: {created_bookmark_id}, URL: '{test_url}', Title: '{original_title}'")
+        logger.info(
+            f"\nUsing managed bookmark ID: {created_bookmark_id}, URL: '{test_url}', Title: '{original_title}'"
+        )
 
         # 2. Verify the bookmark exists by getting it directly
         retrieved_bookmark = karakeep_client.get_a_single_bookmark(
@@ -368,14 +385,13 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
         assert retrieved_bookmark.title == original_title
         logger.info(f"✓ Successfully retrieved the managed bookmark by ID.")
 
-
         # 3. Search for the created bookmark
         # Use a search query that is likely to match the fixture's title
         # The fixture title is "Managed Fixture Bookmark {timestamp}-{random_suffix}"
         # A simple search for "Managed Fixture Bookmark" should work.
         # If the title is very dynamic, searching by URL might be more robust if supported,
         # or by a known part of the title.
-        
+
         # waiting a bit for the indexation just in case
         time.sleep(30)
 
@@ -388,27 +404,38 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
             '"fixture"',
         ]
         for trial, search_query_component in enumerate(search_queries):
-            logger.info(f"\nAttempting to search for bookmark with query based on title: '{search_query_component}'. Retrying multiple times because search is nondeterministic.")
-            search_results = karakeep_client.search_bookmarks(q=search_query_component, limit=100, include_content=False)
+            logger.info(
+                f"\nAttempting to search for bookmark with query based on title: '{search_query_component}'. Retrying multiple times because search is nondeterministic."
+            )
+            search_results = karakeep_client.search_bookmarks(
+                q=search_query_component, limit=100, include_content=False
+            )
             assert isinstance(
                 search_results, datatypes.PaginatedBookmarks
             ), "Search response should be PaginatedBookmarks model"
             assert isinstance(
                 search_results.bookmarks, list
             ), "Search results bookmarks attribute should be a list"
-            
+
             titles_in_search = [b.title for b in search_results.bookmarks]
-            found_in_search = any(b.id == created_bookmark_id for b in search_results.bookmarks)
+            found_in_search = any(
+                b.id == created_bookmark_id for b in search_results.bookmarks
+            )
             if found_in_search:
                 break
             else:
                 time.sleep(3)
-        assert found_in_search, \
-        f"Managed bookmark {created_bookmark_id} (Title: '{original_title}') not found in {trial + 1} different search results for '{search_query_component}'. Titles were: '{titles_in_search}'."
-        logger.info(f"✓ Found managed bookmark in search results for '{search_query_component}'.")
+        assert (
+            found_in_search
+        ), f"Managed bookmark {created_bookmark_id} (Title: '{original_title}') not found in {trial + 1} different search results for '{search_query_component}'. Titles were: '{titles_in_search}'."
+        logger.info(
+            f"✓ Found managed bookmark in search results for '{search_query_component}'."
+        )
 
         # 4. Test CLI search equivalent
-        logger.info(f"\n  Running CLI equivalent: search-bookmarks --q '{search_query_component}' --limit 10 --include-content false")
+        logger.info(
+            f"\n  Running CLI equivalent: search-bookmarks --q '{search_query_component}' --limit 10 --include-content false"
+        )
         try:
             cli_search_command = f"python -m karakeep_python_api search-bookmarks --q '{search_query_component}' --limit 10 --include-content false"
             search_cli_output = subprocess.run(
@@ -418,16 +445,23 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
                 capture_output=True,
                 text=True,
             )
-            assert created_bookmark_id in search_cli_output.stdout, \
-                f"Managed bookmark ID {created_bookmark_id} not found in CLI search output for '{search_query_component}'"
-            logger.info("✓ CLI search command executed successfully and contained the bookmark ID.")
+            assert (
+                created_bookmark_id in search_cli_output.stdout
+            ), f"Managed bookmark ID {created_bookmark_id} not found in CLI search output for '{search_query_component}'"
+            logger.info(
+                "✓ CLI search command executed successfully and contained the bookmark ID."
+            )
         except subprocess.CalledProcessError as e:
             logger.info(f"  CLI search command failed with exit code {e.returncode}")
             logger.info(f"  Stdout: {e.stdout}")
             logger.info(f"  Stderr: {e.stderr}")
-            pytest.fail(f"CLI command 'search-bookmarks --q \"{search_query_component}\"' failed: {e}")
+            pytest.fail(
+                f"CLI command 'search-bookmarks --q \"{search_query_component}\"' failed: {e}"
+            )
         except Exception as e:
-            pytest.fail(f"An unexpected error occurred running the CLI search command: {e}")
+            pytest.fail(
+                f"An unexpected error occurred running the CLI search command: {e}"
+            )
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during bookmark verification/search: {e}")
@@ -439,46 +473,64 @@ def test_create_and_delete_bookmark(karakeep_client: KarakeepAPI, managed_bookma
     # The fixture also handles verification of deletion.
 
 
-def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark):
+def test_update_bookmark_title(
+    karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark
+):
     """Test updating a bookmark's title via API and CLI, using a managed bookmark."""
     created_bookmark_id = managed_bookmark.id
-    original_title = managed_bookmark.title # Get the original title from the fixture
-    
+    original_title = managed_bookmark.title  # Get the original title from the fixture
+
     target_api_title = "this is a test title"
     target_cli_title = "this is a test title (CLI)"
 
     try:
         # The bookmark is already created by the 'managed_bookmark' fixture.
         # We have its ID in created_bookmark_id and its original title.
-        logger.info(f"\nUsing managed bookmark ID: {created_bookmark_id}, Original Title: '{original_title}'")
+        logger.info(
+            f"\nUsing managed bookmark ID: {created_bookmark_id}, Original Title: '{original_title}'"
+        )
 
         # 1. Update the bookmark's title using the API client
-        logger.info(f"\nAttempting to update bookmark ID {created_bookmark_id} title to: '{target_api_title}' via API")
+        logger.info(
+            f"\nAttempting to update bookmark ID {created_bookmark_id} title to: '{target_api_title}' via API"
+        )
         update_payload_api = {"title": target_api_title}
         updated_bookmark_partial = karakeep_client.update_a_bookmark(
             bookmark_id=created_bookmark_id, update_data=update_payload_api
         )
-        assert isinstance(updated_bookmark_partial, dict), "Update response should be a dict"
-        assert updated_bookmark_partial.get("title") == target_api_title, \
-            f"Partial response title '{updated_bookmark_partial.get('title')}' does not match target API title '{target_api_title}'"
-        logger.info(f"✓ API call to update_a_bookmark successful. Partial response title: '{updated_bookmark_partial.get('title')}'")
+        assert isinstance(
+            updated_bookmark_partial, dict
+        ), "Update response should be a dict"
+        assert (
+            updated_bookmark_partial.get("title") == target_api_title
+        ), f"Partial response title '{updated_bookmark_partial.get('title')}' does not match target API title '{target_api_title}'"
+        logger.info(
+            f"✓ API call to update_a_bookmark successful. Partial response title: '{updated_bookmark_partial.get('title')}'"
+        )
 
         # 2. Verify the API update by fetching the bookmark again
-        logger.info(f"\nFetching bookmark ID {created_bookmark_id} to verify API title update.")
+        logger.info(
+            f"\nFetching bookmark ID {created_bookmark_id} to verify API title update."
+        )
         retrieved_bookmark_after_api_update = karakeep_client.get_a_single_bookmark(
             bookmark_id=created_bookmark_id
         )
         assert isinstance(retrieved_bookmark_after_api_update, datatypes.Bookmark)
-        assert retrieved_bookmark_after_api_update.title == target_api_title, \
-            f"Retrieved bookmark title '{retrieved_bookmark_after_api_update.title}' does not match expected API-updated title '{target_api_title}'"
-        logger.info(f"✓ Successfully verified bookmark title updated by API to: '{retrieved_bookmark_after_api_update.title}'")
+        assert (
+            retrieved_bookmark_after_api_update.title == target_api_title
+        ), f"Retrieved bookmark title '{retrieved_bookmark_after_api_update.title}' does not match expected API-updated title '{target_api_title}'"
+        logger.info(
+            f"✓ Successfully verified bookmark title updated by API to: '{retrieved_bookmark_after_api_update.title}'"
+        )
 
         # 3. Test CLI equivalent for updating the bookmark's title
-        logger.info(f"\n  Running CLI equivalent to update title to: '{target_cli_title}'")
+        logger.info(
+            f"\n  Running CLI equivalent to update title to: '{target_cli_title}'"
+        )
         cli_update_payload_json = json.dumps({"title": target_cli_title})
         # Ensure the JSON string is properly quoted for the shell command
         cli_update_command = f"python -m karakeep_python_api update-a-bookmark --bookmark-id {created_bookmark_id} --update-data '{cli_update_payload_json}'"
-        
+
         try:
             subprocess.run(
                 cli_update_command,
@@ -490,14 +542,19 @@ def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: d
             logger.info("✓ CLI update command executed successfully.")
 
             # 4. Verify CLI update by fetching the bookmark again
-            logger.info(f"\nFetching bookmark ID {created_bookmark_id} to verify CLI title update.")
+            logger.info(
+                f"\nFetching bookmark ID {created_bookmark_id} to verify CLI title update."
+            )
             retrieved_bookmark_after_cli_update = karakeep_client.get_a_single_bookmark(
                 bookmark_id=created_bookmark_id
             )
             assert isinstance(retrieved_bookmark_after_cli_update, datatypes.Bookmark)
-            assert retrieved_bookmark_after_cli_update.title == target_cli_title, \
-                f"Retrieved bookmark title '{retrieved_bookmark_after_cli_update.title}' after CLI update does not match expected '{target_cli_title}'"
-            logger.info(f"✓ Successfully verified bookmark title updated by CLI to: '{retrieved_bookmark_after_cli_update.title}'")
+            assert (
+                retrieved_bookmark_after_cli_update.title == target_cli_title
+            ), f"Retrieved bookmark title '{retrieved_bookmark_after_cli_update.title}' after CLI update does not match expected '{target_cli_title}'"
+            logger.info(
+                f"✓ Successfully verified bookmark title updated by CLI to: '{retrieved_bookmark_after_cli_update.title}'"
+            )
 
         except subprocess.CalledProcessError as e:
             logger.info(f"  CLI update command failed with exit code {e.returncode}")
@@ -506,16 +563,22 @@ def test_update_bookmark_title(karakeep_client: KarakeepAPI, managed_bookmark: d
             logger.info(f"  Stderr: {e.stderr}")
             pytest.fail(f"CLI command for update-a-bookmark failed: {e}")
         except Exception as e:
-            pytest.fail(f"An unexpected error occurred running the CLI update command: {e}")
+            pytest.fail(
+                f"An unexpected error occurred running the CLI update command: {e}"
+            )
 
     except (APIError, AuthenticationError) as e:
         pytest.fail(f"API error during bookmark title update test: {e}")
     except Exception as e:
-        pytest.fail(f"An unexpected error occurred during bookmark title update test: {e}")
+        pytest.fail(
+            f"An unexpected error occurred during bookmark title update test: {e}"
+        )
     # No finally block needed for deletion, as 'managed_bookmark' fixture handles it.
 
 
-def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark):
+def test_tag_lifecycle_on_bookmark(
+    karakeep_client: KarakeepAPI, managed_bookmark: datatypes.Bookmark
+):
     """
     Test attaching a tag to a bookmark, updating the tag, detaching it, and deleting it.
     Uses the managed_bookmark fixture.
@@ -529,18 +592,23 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
 
     try:
         # 1. Attach a new tag by name to the bookmark
-        logger.info(f"\nAttempting to attach tag '{initial_tag_name}' to bookmark {bookmark_id}")
+        logger.info(
+            f"\nAttempting to attach tag '{initial_tag_name}' to bookmark {bookmark_id}"
+        )
         attach_response = karakeep_client.attach_tags_to_a_bookmark(
             bookmark_id=bookmark_id, tag_names=[initial_tag_name]
         )
-        assert "attached" in attach_response and len(attach_response["attached"]) == 1, \
-            "Failed to attach tag or response format incorrect"
+        assert (
+            "attached" in attach_response and len(attach_response["attached"]) == 1
+        ), "Failed to attach tag or response format incorrect"
         tag_id_to_manage = attach_response["attached"][0]
         assert isinstance(tag_id_to_manage, str), "Attached tag ID should be a string"
         logger.info(f"✓ Tag '{initial_tag_name}' attached with ID: {tag_id_to_manage}")
 
         # 2. Update the tag's name
-        logger.info(f"\nAttempting to update tag {tag_id_to_manage} to name '{updated_tag_name}'")
+        logger.info(
+            f"\nAttempting to update tag {tag_id_to_manage} to name '{updated_tag_name}'"
+        )
         update_payload = {"name": updated_tag_name}
         updated_tag = karakeep_client.update_a_tag(
             tag_id=tag_id_to_manage, update_data=update_payload
@@ -549,24 +617,38 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
         # assert isinstance(updated_tag, datatypes.Tag), "Update tag response should be Tag model"
         # assert updated_tag.name == updated_tag_name, "Tag name was not updated as expected"
         # logger.info(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag.name}'")
-        assert updated_tag["name"] == updated_tag_name, "Tag name was not updated as expected"
+        assert (
+            updated_tag["name"] == updated_tag_name
+        ), "Tag name was not updated as expected"
         logger.info(f"✓ Tag {tag_id_to_manage} updated to name '{updated_tag['name']}'")
 
         # 3. Verify tag update by getting it directly
-        logger.info(f"\nFetching tag {tag_id_to_manage} to verify its name is '{updated_tag_name}'")
+        logger.info(
+            f"\nFetching tag {tag_id_to_manage} to verify its name is '{updated_tag_name}'"
+        )
         retrieved_tag = karakeep_client.get_a_single_tag(tag_id=tag_id_to_manage)
-        assert isinstance(retrieved_tag, datatypes.Tag), "Get single tag response should be Tag model"
-        assert retrieved_tag.name == updated_tag_name, "Retrieved tag name does not match updated name"
+        assert isinstance(
+            retrieved_tag, datatypes.Tag
+        ), "Get single tag response should be Tag model"
+        assert (
+            retrieved_tag.name == updated_tag_name
+        ), "Retrieved tag name does not match updated name"
         assert retrieved_tag.id == tag_id_to_manage, "Retrieved tag ID does not match"
-        logger.info(f"✓ Verified tag {tag_id_to_manage} has name '{retrieved_tag.name}'")
+        logger.info(
+            f"✓ Verified tag {tag_id_to_manage} has name '{retrieved_tag.name}'"
+        )
 
         # 4. Detach the tag from the bookmark
-        logger.info(f"\nAttempting to detach tag {tag_id_to_manage} from bookmark {bookmark_id}")
+        logger.info(
+            f"\nAttempting to detach tag {tag_id_to_manage} from bookmark {bookmark_id}"
+        )
         detach_response = karakeep_client.detach_tags_from_a_bookmark(
             bookmark_id=bookmark_id, tag_ids=[tag_id_to_manage]
         )
-        assert "detached" in detach_response and tag_id_to_manage in detach_response["detached"], \
-            "Failed to detach tag or response format incorrect"
+        assert (
+            "detached" in detach_response
+            and tag_id_to_manage in detach_response["detached"]
+        ), "Failed to detach tag or response format incorrect"
         logger.info(f"✓ Tag {tag_id_to_manage} detached from bookmark {bookmark_id}")
 
     except (APIError, AuthenticationError) as e:
@@ -588,20 +670,30 @@ def test_tag_lifecycle_on_bookmark(karakeep_client: KarakeepAPI, managed_bookmar
                         f"Tag {tag_id_to_manage} should not exist after deletion, but get_a_single_tag succeeded."
                     )
                 except APIError as e:
-                    assert e.status_code == 404, \
-                        f"Expected 404 Not Found when getting deleted tag, but got status {e.status_code}"
-                    logger.info(f"✓ Confirmed tag {tag_id_to_manage} is deleted (received 404).")
+                    assert (
+                        e.status_code == 404
+                    ), f"Expected 404 Not Found when getting deleted tag, but got status {e.status_code}"
+                    logger.info(
+                        f"✓ Confirmed tag {tag_id_to_manage} is deleted (received 404)."
+                    )
             except (APIError, AuthenticationError) as e:
                 # Log error during cleanup but don't let it mask original test failure
-                logger.info(f"  API error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
+                logger.info(
+                    f"  API error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}"
+                )
             except Exception as e:
-                logger.info(f"  Unexpected error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}")
+                logger.info(
+                    f"  Unexpected error during tag deletion (cleanup) for ID {tag_id_to_manage}: {e}"
+                )
         else:
-            logger.info("\nSkipping tag deletion (cleanup) because tag_id was not obtained or test failed before creation.")
+            logger.info(
+                "\nSkipping tag deletion (cleanup) because tag_id was not obtained or test failed before creation."
+            )
 
 
 # --- Test User Info/Stats Endpoints ---
 
+
 def test_cli_get_bookmarks_count_with_jq(karakeep_client: KarakeepAPI):
     """Test that CLI get-all-bookmarks with --limit returns the expected number of items."""
     # Skip test if jq is not installed
@@ -609,15 +701,15 @@ def test_cli_get_bookmarks_count_with_jq(karakeep_client: KarakeepAPI):
         subprocess.run(["jq", "--version"], check=True, capture_output=True)
     except (subprocess.CalledProcessError, FileNotFoundError):
         pytest.skip("jq is not installed. This test requires jq for JSON processing.")
-    
+
     # Define the limit we want to test
     test_limit = 200
-    
+
     try:
         logger.info(f"\nRunning CLI command: get-all-bookmarks --limit={test_limit}")
         # Use a two-command pipe: Run the CLI command and pipe to jq to count array length
         cmd = f"python -m karakeep_python_api --verbose get-all-bookmarks --limit={test_limit} | jq 'length'"
-        
+
         # Execute the piped command
         result = subprocess.run(
             cmd,
@@ -626,30 +718,36 @@ def test_cli_get_bookmarks_count_with_jq(karakeep_client: KarakeepAPI):
             capture_output=True,
             text=True,
         )
-        
+
         # Parse the output (should be just a number)
         try:
             actual_count = int(result.stdout.strip())
             logger.info(f"✓ Command returned {actual_count} bookmarks")
-            
+
             # Check if we got exactly the requested number or fewer (if there aren't enough bookmarks)
-            assert actual_count <= test_limit, f"Expected at most {test_limit} bookmarks, got {actual_count}"
-            
+            assert (
+                actual_count <= test_limit
+            ), f"Expected at most {test_limit} bookmarks, got {actual_count}"
+
             # Check if we got any bookmarks at all (to ensure the test is meaningful)
             # This could fail if the account has no bookmarks
             assert actual_count > 0, "Expected at least some bookmarks to be returned"
-            
+
             # If the account has enough bookmarks, we should get exactly the limit
             # But we can't assert this because we don't know how many bookmarks exist
             if actual_count < test_limit:
-                logger.info(f"Note: Only {actual_count} bookmarks were returned, which is less than the requested limit of {test_limit}. This is acceptable if the account doesn't have {test_limit} bookmarks.")
+                logger.info(
+                    f"Note: Only {actual_count} bookmarks were returned, which is less than the requested limit of {test_limit}. This is acceptable if the account doesn't have {test_limit} bookmarks."
+                )
             else:
-                logger.info(f"✓ Command returned exactly the requested limit of {test_limit} bookmarks")
-                
+                logger.info(
+                    f"✓ Command returned exactly the requested limit of {test_limit} bookmarks"
+                )
+
         except ValueError:
             logger.error(f"Failed to parse jq output as integer: '{result.stdout}'")
             pytest.fail(f"jq output is not a valid integer: '{result.stdout}'")
-            
+
     except subprocess.CalledProcessError as e:
         logger.error(f"Command failed with exit code {e.returncode}")
         logger.error(f"Stdout: {e.stdout}")
@@ -691,7 +789,7 @@ def test_get_current_user_stats(karakeep_client: KarakeepAPI):
             "python -m karakeep_python_api get-current-user-stats",
             shell=True,
             check=True,
-            capture_output=True, # Capture output to avoid logger.infoing it during tests unless verbose
+            capture_output=True,  # Capture output to avoid logger.infoing it during tests unless verbose
             text=True,
         )
         logger.info("✓ CLI command executed successfully.")
